==> kubernetes-model-1.0.27-sources.jar: io/fabric8/kubernetes/api/model/NodeSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class NodeSpecBuilder extends NodeSpecFluent<NodeSpecBuilder> implements VisitableBuilder<NodeSpec,NodeSpecBuilder>{

     NodeSpecFluent<?> fluent;
public NodeSpecBuilder(){
    this(new NodeSpec());
}
public NodeSpecBuilder( NodeSpecFluent<?> fluent ){
    this(fluent, new NodeSpec());
}
public NodeSpecBuilder( NodeSpecFluent<?> fluent , NodeSpec instance ){
    this.fluent = fluent; fluent.withExternalID(instance.getExternalID()); fluent.withPodCIDR(instance.getPodCIDR()); fluent.withProviderID(instance.getProviderID()); fluent.withUnschedulable(instance.getUnschedulable()); 
}
public NodeSpecBuilder( NodeSpec instance ){
    this.fluent = this; this.withExternalID(instance.getExternalID()); this.withPodCIDR(instance.getPodCIDR()); this.withProviderID(instance.getProviderID()); this.withUnschedulable(instance.getUnschedulable()); 
}

public EditableNodeSpec build(){
    EditableNodeSpec buildable = new EditableNodeSpec(fluent.getExternalID(),fluent.getPodCIDR(),fluent.getProviderID(),fluent.isUnschedulable());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NodeSpecBuilder that = (NodeSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/NodeSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class NodeSpecBuilder extends NodeSpecFluentImpl<NodeSpecBuilder> implements VisitableBuilder<NodeSpec,NodeSpecBuilder>{

     NodeSpecFluent<?> fluent;
public NodeSpecBuilder(){
    this(new NodeSpec());
}
public NodeSpecBuilder( NodeSpecFluent<?> fluent ){
    this(fluent, new NodeSpec());
}
public NodeSpecBuilder( NodeSpecFluent<?> fluent , NodeSpec instance ){
    this.fluent = fluent; fluent.withExternalID(instance.getExternalID()); fluent.withPodCIDR(instance.getPodCIDR()); fluent.withProviderID(instance.getProviderID()); fluent.withUnschedulable(instance.getUnschedulable()); 
}
public NodeSpecBuilder( NodeSpec instance ){
    this.fluent = this; this.withExternalID(instance.getExternalID()); this.withPodCIDR(instance.getPodCIDR()); this.withProviderID(instance.getProviderID()); this.withUnschedulable(instance.getUnschedulable()); 
}

public EditableNodeSpec build(){
    EditableNodeSpec buildable = new EditableNodeSpec(fluent.getExternalID(),fluent.getPodCIDR(),fluent.getProviderID(),fluent.isUnschedulable());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NodeSpecBuilder that = (NodeSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
